@@ -1,6 +1,7 @@
 from wows_api_async.sub_node import SubNode
 from wows_api_async.tools import dict_key_transform, stringize
 from .models import Achievements, AccountInfo
+from ..cache.tools import dict_cache, DictCacheContext
 
 
 class Account(SubNode):
@@ -11,4 +12,7 @@ class Account(SubNode):
         return {int(aid): Achievements(**dict_key_transform(data['battle'], str.lower)) for aid, data in resp.data.items()}
 
     async def info(self, account_ids: list[int]) -> dict[int, AccountInfo]:
-        return await self._fetch_model_dict('info', AccountInfo, account_id = stringize(account_ids))
+        async with dict_cache(self._cache, "encyclopedia_ships_", account_ids) as context:  # type: DictCacheContext
+            if context.id_list:
+                context.data.update(await self._fetch_model_dict('info', AccountInfo, account_id = stringize(context.id_list)))
+        return context.data
